==> massxpert-2.0.5.tar.gz: massxpert-2.0.5/gui/mainWindow.hpp <==
/* massXpert - the true massist's program.
   --------------------------------------
   Copyright(C) 2006,2007 Filippo Rusconi

   http://www.filomace.org/massXpert

   This file is part of the massXpert project.

   The massxpert project is the successor to the "GNU polyxmass"
   project that is an official GNU project package(see
   www.gnu.org). The massXpert project is not endorsed by the GNU
   project, although it is released ---in its entirety--- under the
   GNU General Public License. A huge part of the code in massXpert
   is actually a C++ rewrite of code in GNU polyxmass. As such
   massXpert was started at the Centre National de la Recherche
   Scientifique(FRANCE), that granted me the formal authorization to
   publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License version 3, as published by the Free Software Foundation.
   

   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this software; if not, write to the

   Free Software Foundation, Inc.,

   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/


#ifndef MAIN_WINDOW_HPP
#define MAIN_WINDOW_HPP


/////////////////////// Qt includes
#include <QMainWindow>
#include <QDir>
#include <QStringList>


class QAction;
class QMenu;
class QTextEdit;


namespace massXpert
{
  class MainWindow : public QMainWindow
  {
    Q_OBJECT

    private:
    QMenu *fileMenu;

    QMenu *xpertDefMenu;
    QMenu *xpertCalcMenu;
    QMenu *xpertEditMenu;
    QMenu *xpertMinerMenu;
    
    QMenu *helpMenu;

    QAction *openPolChemDefAct;
    QAction *newPolChemDefAct;

    QAction *newCalculatorAct;

    QAction *openSequenceAct;
    QAction *openSampleSequenceAct;
    QAction *newSequenceAct;

    QAction *mzLabAct;
    
    QAction *exitAct;

    QAction *aboutAct;
    QAction *aboutQtAct;
  

    ////////////////// PLUGIN STUFF //////////////////////
    ////////////////// PLUGIN STUFF //////////////////////

    QMenu *pluginMenu;

    QDir m_pluginDir;
  
    void loadPlugins();
    void populatePluginMenus(QObject *);
    void addToMenu(QObject *, const QStringList &, QMenu *,
		    const char *);
  
    ////////////////// PLUGIN STUFF //////////////////////

    void createActions();
    void createMenus();
    void createStatusBar();

  private slots:
    void openPolChemDef();
    void newPolChemDef();

    void newCalculator();

    void openSequence();
    void openSampleSequence();
    void newSequence();

    void mzLab();
    
    void about();

    void seqToolsPlugin();
    void massListSorterPlugin();
    void numeralsLocaleConverterPlugin();
    
    
  protected:
    void closeEvent(QCloseEvent *);

  public:
    MainWindow();

  signals:
    void aboutToClose();
  };

} // namespace massXpert


#endif /* MAINWINDOW_HPP */

==> massxpert_3.6.0.orig.tar.gz: massxpert-3.6.0/gui/mainWindow.hpp <==
/* massXpert - the true massist's program.
   --------------------------------------
   Copyright(C) 2006,2007 Filippo Rusconi

   http://www.filomace.org/massXpert

   This file is part of the massXpert project.

   The massxpert project is the successor to the "GNU polyxmass"
   project that is an official GNU project package(see
   www.gnu.org). The massXpert project is not endorsed by the GNU
   project, although it is released ---in its entirety--- under the
   GNU General Public License. A huge part of the code in massXpert
   is actually a C++ rewrite of code in GNU polyxmass. As such
   massXpert was started at the Centre National de la Recherche
   Scientifique(FRANCE), that granted me the formal authorization to
   publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License version 3, as published by the Free Software Foundation.
   

   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this software; if not, write to the

   Free Software Foundation, Inc.,

   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/


#ifndef MAIN_WINDOW_HPP
#define MAIN_WINDOW_HPP


/////////////////////// Qt includes
#include <QMainWindow>
#include <QDir>
#include <QStringList>


class QAction;
class QMenu;
class QTextEdit;


namespace massXpert
{
  class MainWindow : public QMainWindow
  {
    Q_OBJECT

    private:
    QMenu *fileMenu;

    QMenu *xpertDefMenu;
    QMenu *xpertCalcMenu;
    QMenu *xpertEditMenu;
    QMenu *xpertMinerMenu;
    QMenu *toolsMenu;

    QMenu *helpMenu;

    QAction *openPolChemDefAct;
    QAction *newPolChemDefAct;

    QAction *newCalculatorAct;

    QAction *openSequenceAct;
    QAction *openSampleSequenceAct;
    QAction *newSequenceAct;

    QAction *mzLabAct;
    
    QAction *massListSorterAct;
    QAction *numeralsLocaleConverterAct;
    QAction *seqToolsAct;
    
    QAction *exitAct;

    QAction *aboutAct;
    QAction *aboutQtAct;
  
    void addToMenu(QObject *, const QStringList &, QMenu *,
		    const char *);
  
    void createActions();
    void createMenus();
    void createStatusBar();

  private slots:
    void openPolChemDef();
    void newPolChemDef();

    void newCalculator();

    void openSequence();
    void openSampleSequence();
    void newSequence();

    void mzLab();
    
    void about();

    void massListSorter();
    void numeralsLocaleConverter();
    void seqTools();
    
  protected:
    void closeEvent(QCloseEvent *);

  public:
    MainWindow();

  signals:
    void aboutToClose();
  };

} // namespace massXpert


#endif /* MAINWINDOW_HPP */
